@@ -60,7 +60,7 @@ def copytree(src, dst, ignore=shutil.ignore_patterns(IGNORE_PATTERNS)):
 
 
 def copy_files(template):
-    print ("Copying files from template...")
+    print("Copying files from template...")
     try:
         if not is_chicken:
             run_file = os.path.realpath(__file__)
@@ -79,7 +79,7 @@ def copy_files(template):
 
 
 def git_init():
-    print ("Initializing GIT...")
+    print("Initializing GIT...")
     if not is_chicken:
         try:
             os_call('git init')
@@ -88,7 +88,7 @@ def git_init():
 
 
 def rename_files(project):
-    print ("Modifying copied files names...")
+    print("Modifying copied files names...")
     try:
         if not is_chicken:
             shutil.move('packagesample', project)
@@ -101,7 +101,7 @@ def rename_files(project):
 
 
 def perform_replaces(project):
-    print ("Modifying copied files content...")
+    print("Modifying copied files content...")
     try:
         if not is_chicken:
             files = ['setup.py', 'README.rst', 'run.py', 'MANIFEST.in',
@@ -138,7 +138,7 @@ def has_virtualenvwrapper():
 
 
 def create_venv(project):
-    print ("Creating virtualenv...")
+    print("Creating virtualenv...")
     try:
         if not is_chicken:
             log.debug('Trying to create virtualenv')
@@ -152,7 +152,7 @@ def create_venv(project):
                     full_env_path = os.path.join(env_path + project)
                     os_call('virtualenv ' + full_env_path)
 
-            print ("\nSUCCESS!!!")
+            print("\nSUCCESS!!!")
 
             activateL = full_env_path + '/bin/activate'
             activateW = full_env_path + '/Scripts/activate'
@@ -162,15 +162,18 @@ def create_venv(project):
                 activate = activateL
 
             if os.path.isfile(activate):
-                print("Please execute 'source " + activate + "' to enter into your virtualenv")
+                print("Please execute 'source " + activate +
+                      "' to enter into your virtualenv")
                 # http://stackoverflow.com/questions/6943208/activate-a-virtualenv-with-a-python-script
 
                 if has_virtualenv():
                     if os.path.isfile('requirements.txt'):
-                        print("Then please execute 'pip install -r requirements.txt'")
+                        print("Then please execute \
+                              'pip install -r requirements.txt'")
                         # os_call('pip install -r requirements.txt')
                     if os.path.isfile('requirements-dev.txt'):
-                        print("And after please execute 'pip install -r requirements-dev.txt'")
+                        print("And after please execute \
+                              'pip install -r requirements-dev.txt'")
                         # os_call('pip install -r requirements-dev.txt')
         return True
     except Exception, e:
@@ -189,7 +192,7 @@ def main(template, chicken):
         message = 'Current directory is not empty, so machete cannot run :-('
         log.warn(message)
         print(message)
-        exit(0)
+        exit(1)
 
     project = os.path.basename(os.getcwd()).replace('-', '_')
     git_init()
@@ -197,6 +200,8 @@ def main(template, chicken):
         if rename_files(project):
             if perform_replaces(project):
                 if create_venv(project):
-                    print ('\nmachete says: "Its done!"')
-                    print ('\nAfter these steps, run your app with "python run.py"')
-                    print ('Check for the log file under ' + tempfile.gettempdir())
+                    print('\nmachete says: "Its done!"')
+                    print('\nAfter these steps, run your \
+                          app with "python run.py"')
+                    print('Check for the log file under ' +
+                          tempfile.gettempdir())
